import { Sequelize, DataTypes, Model, Optional } from "sequelize";

interface BoatAttributes {
  id: string;
  name: string;
  status: boolean;
  tags: Array<string>;
  minP: number;
  maxP: number;
}

export interface BoatAttributesInput extends Optional<BoatAttributes, "id"> { }

class Boat extends Model<BoatAttributes, BoatAttributesInput> implements BoatAttributes {
  declare id: string;
  declare minP: number;
  declare maxP: number;
  declare name: string;
  declare status: boolean;
  declare tags: Array<string>;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initBoat = async (sequelizeConnection: Sequelize) => {
  Boat.init(
  {
    id: {
      type: DataTypes.UUID,
      defaultValue: DataTypes.UUIDV4,
      primaryKey: true,
      allowNull: false,
    },
    name: {
      type: new DataTypes.STRING(),
      allowNull: false,
    },
    status: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
    },
    tags: {
      type: new DataTypes.ARRAY(DataTypes.STRING),
    },
    minP:{
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    maxP:{
      type: DataTypes.INTEGER,
      allowNull: false,
    }
  },
  {
    tableName: "boat",
    sequelize: sequelizeConnection,
  }
);
};

export default Boat;
