import { Sequelize, DataTypes, Model, Optional } from "sequelize";

interface BoatHasBoatTypeAttributes {
  boatid: string;
  boattypeid: string;
}

export interface BoatHasBoatTypeAttributesInput
  extends Optional<BoatHasBoatTypeAttributes, "boatid"|"boattypeid"> {} // optional

class BoatHasBoatType
  extends Model<BoatHasBoatTypeAttributes, BoatHasBoatTypeAttributesInput>
  implements BoatHasBoatTypeAttributes
{
  declare boatid: string;
  declare boattypeid: string;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initBoatHasBoatType = async (sequelizeConnection: Sequelize) => {
  BoatHasBoatType.init(
    {
      boatid: {
        type: DataTypes.UUID,
        allowNull: false,
        primaryKey: true,
        references: {
          model: "boat",
          key: "id",
        },
      },
      boattypeid: {
        type: DataTypes.UUID,
        allowNull: false,
        primaryKey: true,
        references: {
          model: "boattype",
          key: "id",
        },
      },
    },

    {
      tableName: "boathasboattype",
      sequelize: sequelizeConnection,
    }
  );
};

export default BoatHasBoatType;
